import iam = require('@aws-cdk/aws-iam');
import cdk = require('@aws-cdk/core');
/**
 * AWS SDK service metadata.
 */
export declare type AwsSdkMetadata = {
    [key: string]: any;
};
/**
 * An AWS SDK call.
 */
export interface AwsSdkCall {
    /**
     * The service to call
     *
     * @see https://docs.aws.amazon.com/AWSJavaScriptSDK/latest/index.html
     */
    readonly service: string;
    /**
     * The service action to call
     *
     * @see https://docs.aws.amazon.com/AWSJavaScriptSDK/latest/index.html
     */
    readonly action: string;
    /**
     * The parameters for the service action
     *
     * @see https://docs.aws.amazon.com/AWSJavaScriptSDK/latest/index.html
     */
    readonly parameters?: any;
    /**
     * The path to the data in the API call response to use as the physical
     * resource id. Either `physicalResourceId` or `physicalResourceIdPath`
     * must be specified for onCreate or onUpdate calls.
     *
     * @default no path
     */
    readonly physicalResourceIdPath?: string;
    /**
     * The physical resource id of the custom resource for this call. Either
     * `physicalResourceId` or `physicalResourceIdPath` must be specified for
     * onCreate or onUpdate calls.
     *
     * @default no physical resource id
     */
    readonly physicalResourceId?: string;
    /**
     * The regex pattern to use to catch API errors. The `code` property of the
     * `Error` object will be tested against this pattern. If there is a match an
     * error will not be thrown.
     *
     * @default do not catch errors
     */
    readonly catchErrorPattern?: string;
    /**
     * API version to use for the service
     *
     * @see https://docs.aws.amazon.com/sdk-for-javascript/v2/developer-guide/locking-api-versions.html
     * @default use latest available API version
     */
    readonly apiVersion?: string;
    /**
     * Restrict the data returned by the custom resource to a specific path in
     * the API response. Use this to limit the data returned by the custom
     * resource if working with API calls that could potentially result in custom
     * response objects exceeding the hard limit of 4096 bytes.
     *
     * Example for ECS / updateService: 'service.deploymentConfiguration.maximumPercent'
     *
     * @default return all data
     */
    readonly outputPath?: string;
}
export interface AwsCustomResourceProps {
    /**
     * The AWS SDK call to make when the resource is created.
     * At least onCreate, onUpdate or onDelete must be specified.
     *
     * @default the call when the resource is updated
     */
    readonly onCreate?: AwsSdkCall;
    /**
     * The AWS SDK call to make when the resource is updated
     *
     * @default no call
     */
    readonly onUpdate?: AwsSdkCall;
    /**
     * THe AWS SDK call to make when the resource is deleted
     *
     * @default no call
     */
    readonly onDelete?: AwsSdkCall;
    /**
     * The IAM policy statements to allow the different calls. Use only if
     * resource restriction is needed.
     *
     * @default extract the permissions from the calls
     */
    readonly policyStatements?: iam.PolicyStatement[];
}
export declare class AwsCustomResource extends cdk.Construct {
    private readonly customResource;
    constructor(scope: cdk.Construct, id: string, props: AwsCustomResourceProps);
    /**
     * Returns response data for the AWS SDK call.
     *
     * Example for S3 / listBucket : 'Buckets.0.Name'
     *
     * @param dataPath the path to the data
     */
    getData(dataPath: string): cdk.IResolvable;
}
